class TivioDataWidget {
  final String id;
  final String name;

  TivioDataWidget(this.id, this.name);

  TivioDataWidget.fromJson(Map json)
      : id = json['id'],
        name = json['name'];
}

class _ChannelImages {
  final String? logo;
  final String? cover;

  _ChannelImages(this.logo, this.cover);
}

class TivioDataChannel {
  final String id;
  final String name;
  final _ChannelImages images;

  TivioDataChannel(this.id, this.name, this.images);

  TivioDataChannel.fromJson(Map json)
      : id = json['id'],
        name = json['name'],
        images = _ChannelImages(json['headerLogo'], json['cover']);

  static TivioDataPagination<TivioDataChannel> fromJsonPaginated(Map json) {
    var records = json['records'] ?? [];
    var channels = records
        .where((record) => (record['id'] != null && record['name'] != null))
        .map<TivioDataChannel>((record) => TivioDataChannel.fromJson(record))
        .toList();

    return TivioDataPagination(channels, json['hasNextPage'] ?? false);
  }
}

class TivioDataSection {
  final String id;
  final String name;

  TivioDataSection(this.id, this.name);

  TivioDataSection.fromJson(Map json)
      : id = json['id'],
        name = json['name'];

  static TivioDataPagination<TivioDataSection> fromJsonPaginated(Map data) {
    var records = data['records'] ?? [];
    var sections = records
        .where((record) => (record['id'] != null && record['name'] != null))
        .map<TivioDataSection>((record) => TivioDataSection.fromJson(record))
        .toList();

    return TivioDataPagination(sections, data['hasNextPage'] ?? false);
  }
}

class _VideoImages {
  final String? cover;

  _VideoImages(this.cover);
}

class _Monetization {
  final num? price;
  final String? type;

  _Monetization(this.price, this.type);
}

class TivioDataPlaylistItem {
  final String name;
  final String url;
  final Duration duration;

  TivioDataPlaylistItem(this.name, this.url, this.duration);
}

class TivioDataVideo {
  final String id;
  final String name;
  final Duration duration;
  final DateTime? created;
  final String? url;
  final _VideoImages images;
  final bool isPlaylist;
  final List<TivioDataPlaylistItem> playlistItems;
  final _Monetization? monetization;

  TivioDataVideo(
    this.id,
    this.name,
    this.duration,
    this.created,
    this.url,
    this.images,
    this.isPlaylist,
    this.playlistItems,
    this.monetization,
  );

  TivioDataVideo.fromJson(Map json)
      : id = json['id'],
        name = json['name'],
        duration = Duration(milliseconds: json['duration'] ?? 0),
        created = (json['created'] != null) ? DateTime.parse(json['created']) : null,
        url = json['url'],
        images = _VideoImages(json['cover']),
        isPlaylist = json['isPlaylist'] ?? false,
        playlistItems = [],
        monetization = (json['monetization'] != null)
            ? _Monetization(json['monetization']['name'], json['monetization']['price'])
            : null;

  static TivioDataPagination<TivioDataVideo> fromJsonPaginated(Map data) {
    var records = data['records'] ?? [];
    var videos = records
        .where((record) => (record['id'] != null && record['name'] != null))
        .map<TivioDataVideo>((record) => TivioDataVideo.fromJson(record))
        .toList();

    return TivioDataPagination(videos, data['hasNextPage'] ?? false);
  }
}

class TivioDataPagination<T> {
  final List<T> records;
  final bool hasNextPage;

  TivioDataPagination(this.records, this.hasNextPage);
}
