import '../utils/enum.dart';

enum TivioPlayerWrapperInputSourceType {
  Vod,
  Advertisement,
}

abstract class TivioPlayerInputSource {
  String? id;
  String? uri;
  Duration? skipDelay;
  Duration? duration;
  TivioPlayerWrapperInputSourceType? type;

  toObject();
}

class TivioPlayerAdSource extends TivioPlayerInputSource {
  final String? id;
  final String? uri;
  final String? name;
  final String? description;
  final Duration? skipDelay;
  final Duration? duration;
  final bool? isSkippable;
  final TivioPlayerWrapperInputSourceType type = TivioPlayerWrapperInputSourceType.Advertisement;

  TivioPlayerAdSource({
    this.id,
    this.uri,
    this.name,
    this.description,
    this.duration,
    this.skipDelay,
    this.isSkippable,
  });

  TivioPlayerAdSource.fromJson(Map json)
      : id = json['id'],
        uri = json['uri'],
        name = json['name'],
        description = json['description'],
        duration = (json['durationMs'] != null) ? Duration(milliseconds: json['durationMs']) : null,
        skipDelay = (json['skipDelayMs'] != null) ? Duration(milliseconds: json['skipDelayMs']) : null,
        isSkippable = json['isSkippable'];

  toObject() {
    return {
      'uri': uri,
      'id': id,
      'name': name,
      'description': description,
      'duration': (duration != null) ? duration!.inMilliseconds : null,
      'skipDelay': (skipDelay != null) ? skipDelay!.inMilliseconds : null,
      'isSkippable': isSkippable,
      'type': enumToString(this.type),
    };
  }
}

class TivioPlayerVodSource extends TivioPlayerInputSource {
  final String? id;
  final String? uri;
  final String? name;
  final String? description;
  final TivioPlayerWrapperInputSourceType type = TivioPlayerWrapperInputSourceType.Vod;

  TivioPlayerVodSource({
    this.id,
    this.uri,
    this.name,
    this.description,
  });

  TivioPlayerVodSource.fromJson(Map json)
      : id = json['videoId'],
        uri = json['uri'],
        name = json['name'],
        description = json['description'];

  toObject() {
    return {
      'uri': uri,
      'id': id,
      'name': name,
      'description': description,
      'type': enumToString(this.type),
    };
  }
}
